# coding: utf-8
from geoalchemy2 import Geometry
from sqlalchemy import BigInteger, Column, DateTime, Float, Integer, SmallInteger, Table, Text, TEXT, BIGINT
from sqlalchemy.dialects.postgresql import HSTORE
from sqlalchemy.dialects.postgresql import ARRAY
from sqlalchemy.ext.declarative import declarative_base


Base = declarative_base()
metadata = Base.metadata

t_osm_line = Table(
    'osm_line', metadata,
    Column('osm_id', BigInteger, index=True),
    Column('access', Text),
    Column('addr:city', Text),
    Column('addr:housenumber', Text),
    Column('addr:interpolation', Text),
    Column('addr:place', Text),
    Column('addr:postcode', Text),
    Column('addr:street', Text),
    Column('addr:country', Text),
    Column('admin_level', Text),
    Column('aerialway', Text),
    Column('aeroway', Text),
    Column('amenity', Text),
    Column('area', Text),
    Column('barrier', Text),
    Column('brand', Text),
    Column('bridge', Text),
    Column('boundary', Text),
    Column('building', Text),
    Column('bus', Text),
    Column('contact:phone', Text),
    Column('cuisine', Text),
    Column('denomination', Text),
    Column('drinkable', Text),
    Column('emergency', Text),
    Column('entrance', Text),
    Column('foot', Text),
    Column('frequency', Text),
    Column('generator:source', Text),
    Column('height', Text),
    Column('highway', Text),
    Column('historic', Text),
    Column('information', Text),
    Column('junction', Text),
    Column('landuse', Text),
    Column('layer', Text),
    Column('leisure', Text),
    Column('man_made', Text),
    Column('maxspeed', Text),
    Column('military', Text),
    Column('name', Text),
    Column('int_name', Text),
    Column('name:en', Text),
    Column('name:de', Text),
    Column('name:fr', Text),
    Column('name:es', Text),
    Column('natural', Text),
    Column('office', Text),
    Column('oneway', Text),
    Column('opening_hours', Text),
    Column('operator', Text),
    Column('phone', Text),
    Column('power', Text),
    Column('power_source', Text),
    Column('parking', Text),
    Column('place', Text),
    Column('population', Text),
    Column('public_transport', Text),
    Column('recycling:glass', Text),
    Column('recycling:paper', Text),
    Column('recycling:clothes', Text),
    Column('recycling:scrap_metal', Text),
    Column('railway', Text),
    Column('ref', Text),
    Column('religion', Text),
    Column('route', Text),
    Column('service', Text),
    Column('shop', Text),
    Column('sport', Text),
    Column('tourism', Text),
    Column('tower:type', Text),
    Column('tracktype', Text),
    Column('traffic_calming', Text),
    Column('train', Text),
    Column('tram', Text),
    Column('tunnel', Text),
    Column('type', Text),
    Column('vending', Text),
    Column('voltage', Text),
    Column('water', Text),
    Column('waterway', Text),
    Column('website', Text),
    Column('wetland', Text),
    Column('width', Text),
    Column('wikipedia', Text),
    Column('z_order', SmallInteger),
    Column('way_area', Float),
    Column('osm_timestamp', DateTime),
    Column('osm_version', Text),
    Column('tags', HSTORE),
    Column('way', Geometry(geometry_type='LineString', srid=900913), index=True)
)


class OsmNode(Base):
    __tablename__ = 'osm_nodes'

    id = Column(BigInteger, primary_key=True)
    lat = Column(Integer, nullable=False)
    lon = Column(Integer, nullable=False)
    tags = Column(ARRAY(TEXT()))


t_osm_point = Table(
    'osm_point', metadata,
    Column('osm_id', BigInteger, index=True),
    Column('access', Text),
    Column('addr:city', Text),
    Column('addr:housenumber', Text),
    Column('addr:interpolation', Text),
    Column('addr:place', Text),
    Column('addr:postcode', Text),
    Column('addr:street', Text),
    Column('addr:country', Text),
    Column('admin_level', Text),
    Column('aerialway', Text),
    Column('aeroway', Text),
    Column('amenity', Text),
    Column('area', Text),
    Column('barrier', Text),
    Column('brand', Text),
    Column('bridge', Text),
    Column('boundary', Text),
    Column('building', Text),
    Column('bus', Text),
    Column('contact:phone', Text),
    Column('cuisine', Text),
    Column('denomination', Text),
    Column('drinkable', Text),
    Column('ele', Text),
    Column('emergency', Text),
    Column('entrance', Text),
    Column('foot', Text),
    Column('frequency', Text),
    Column('generator:source', Text),
    Column('height', Text),
    Column('highway', Text),
    Column('historic', Text),
    Column('information', Text),
    Column('junction', Text),
    Column('landuse', Text),
    Column('layer', Text),
    Column('leisure', Text),
    Column('man_made', Text),
    Column('maxspeed', Text),
    Column('military', Text),
    Column('name', Text),
    Column('int_name', Text),
    Column('name:en', Text),
    Column('name:de', Text),
    Column('name:fr', Text),
    Column('name:es', Text),
    Column('natural', Text),
    Column('office', Text),
    Column('oneway', Text),
    Column('opening_hours', Text),
    Column('operator', Text),
    Column('phone', Text),
    Column('power', Text),
    Column('power_source', Text),
    Column('parking', Text),
    Column('place', Text),
    Column('population', Text),
    Column('public_transport', Text),
    Column('recycling:glass', Text),
    Column('recycling:paper', Text),
    Column('recycling:clothes', Text),
    Column('recycling:scrap_metal', Text),
    Column('railway', Text),
    Column('ref', Text),
    Column('religion', Text),
    Column('route', Text),
    Column('service', Text),
    Column('shop', Text),
    Column('sport', Text),
    Column('tourism', Text),
    Column('tower:type', Text),
    Column('traffic_calming', Text),
    Column('train', Text),
    Column('tram', Text),
    Column('tunnel', Text),
    Column('type', Text),
    Column('vending', Text),
    Column('voltage', Text),
    Column('water', Text),
    Column('waterway', Text),
    Column('website', Text),
    Column('wetland', Text),
    Column('width', Text),
    Column('wikipedia', Text),
    Column('z_order', SmallInteger),
    Column('osm_timestamp', DateTime),
    Column('osm_version', Text),
    Column('tags', HSTORE),
    Column('way', Geometry(geometry_type='Point', srid=900913), index=True)
)


t_osm_polygon = Table(
    'osm_polygon', metadata,
    Column('osm_id', BigInteger, index=True),
    Column('access', Text),
    Column('addr:city', Text),
    Column('addr:housenumber', Text),
    Column('addr:interpolation', Text),
    Column('addr:place', Text),
    Column('addr:postcode', Text),
    Column('addr:street', Text),
    Column('addr:country', Text),
    Column('admin_level', Text),
    Column('aerialway', Text),
    Column('aeroway', Text),
    Column('amenity', Text),
    Column('area', Text),
    Column('barrier', Text),
    Column('brand', Text),
    Column('bridge', Text),
    Column('boundary', Text),
    Column('building', Text),
    Column('bus', Text),
    Column('contact:phone', Text),
    Column('cuisine', Text),
    Column('denomination', Text),
    Column('drinkable', Text),
    Column('emergency', Text),
    Column('entrance', Text),
    Column('foot', Text),
    Column('frequency', Text),
    Column('generator:source', Text),
    Column('height', Text),
    Column('highway', Text),
    Column('historic', Text),
    Column('information', Text),
    Column('junction', Text),
    Column('landuse', Text),
    Column('layer', Text),
    Column('leisure', Text),
    Column('man_made', Text),
    Column('maxspeed', Text),
    Column('military', Text),
    Column('name', Text),
    Column('int_name', Text),
    Column('name:en', Text),
    Column('name:de', Text),
    Column('name:fr', Text),
    Column('name:es', Text),
    Column('natural', Text),
    Column('office', Text),
    Column('oneway', Text),
    Column('opening_hours', Text),
    Column('operator', Text),
    Column('phone', Text),
    Column('power', Text),
    Column('power_source', Text),
    Column('parking', Text),
    Column('place', Text),
    Column('population', Text),
    Column('public_transport', Text),
    Column('recycling:glass', Text),
    Column('recycling:paper', Text),
    Column('recycling:clothes', Text),
    Column('recycling:scrap_metal', Text),
    Column('railway', Text),
    Column('ref', Text),
    Column('religion', Text),
    Column('route', Text),
    Column('service', Text),
    Column('shop', Text),
    Column('sport', Text),
    Column('tourism', Text),
    Column('tower:type', Text),
    Column('tracktype', Text),
    Column('traffic_calming', Text),
    Column('train', Text),
    Column('tram', Text),
    Column('tunnel', Text),
    Column('type', Text),
    Column('vending', Text),
    Column('voltage', Text),
    Column('water', Text),
    Column('waterway', Text),
    Column('website', Text),
    Column('wetland', Text),
    Column('width', Text),
    Column('wikipedia', Text),
    Column('z_order', SmallInteger),
    Column('way_area', Float),
    Column('osm_timestamp', DateTime),
    Column('osm_version', Text),
    Column('tags', HSTORE),
    Column('way', Geometry(geometry_type='Geometry', srid=900913), index=True)
)


class OsmRel(Base):
    __tablename__ = 'osm_rels'

    id = Column(BigInteger, primary_key=True)
    way_off = Column(SmallInteger)
    rel_off = Column(SmallInteger)
    parts = Column(ARRAY(BIGINT()), index=True)
    members = Column(ARRAY(TEXT()))
    tags = Column(ARRAY(TEXT()))


t_osm_roads = Table(
    'osm_roads', metadata,
    Column('osm_id', BigInteger, index=True),
    Column('access', Text),
    Column('addr:city', Text),
    Column('addr:housenumber', Text),
    Column('addr:interpolation', Text),
    Column('addr:place', Text),
    Column('addr:postcode', Text),
    Column('addr:street', Text),
    Column('addr:country', Text),
    Column('admin_level', Text),
    Column('aerialway', Text),
    Column('aeroway', Text),
    Column('amenity', Text),
    Column('area', Text),
    Column('barrier', Text),
    Column('brand', Text),
    Column('bridge', Text),
    Column('boundary', Text),
    Column('building', Text),
    Column('bus', Text),
    Column('contact:phone', Text),
    Column('cuisine', Text),
    Column('denomination', Text),
    Column('drinkable', Text),
    Column('emergency', Text),
    Column('entrance', Text),
    Column('foot', Text),
    Column('frequency', Text),
    Column('generator:source', Text),
    Column('height', Text),
    Column('highway', Text),
    Column('historic', Text),
    Column('information', Text),
    Column('junction', Text),
    Column('landuse', Text),
    Column('layer', Text),
    Column('leisure', Text),
    Column('man_made', Text),
    Column('maxspeed', Text),
    Column('military', Text),
    Column('name', Text),
    Column('int_name', Text),
    Column('name:en', Text),
    Column('name:de', Text),
    Column('name:fr', Text),
    Column('name:es', Text),
    Column('natural', Text),
    Column('office', Text),
    Column('oneway', Text),
    Column('opening_hours', Text),
    Column('operator', Text),
    Column('phone', Text),
    Column('power', Text),
    Column('power_source', Text),
    Column('parking', Text),
    Column('place', Text),
    Column('population', Text),
    Column('public_transport', Text),
    Column('recycling:glass', Text),
    Column('recycling:paper', Text),
    Column('recycling:clothes', Text),
    Column('recycling:scrap_metal', Text),
    Column('railway', Text),
    Column('ref', Text),
    Column('religion', Text),
    Column('route', Text),
    Column('service', Text),
    Column('shop', Text),
    Column('sport', Text),
    Column('tourism', Text),
    Column('tower:type', Text),
    Column('tracktype', Text),
    Column('traffic_calming', Text),
    Column('train', Text),
    Column('tram', Text),
    Column('tunnel', Text),
    Column('type', Text),
    Column('vending', Text),
    Column('voltage', Text),
    Column('water', Text),
    Column('waterway', Text),
    Column('website', Text),
    Column('wetland', Text),
    Column('width', Text),
    Column('wikipedia', Text),
    Column('z_order', SmallInteger),
    Column('way_area', Float),
    Column('osm_timestamp', DateTime),
    Column('osm_version', Text),
    Column('tags', HSTORE),
    Column('way', Geometry(geometry_type='LineString', srid=900913), index=True)
)


class OsmWay(Base):
    __tablename__ = 'osm_ways'

    id = Column(BigInteger, primary_key=True)
    nodes = Column(ARRAY(BIGINT()), nullable=False, index=True)
    tags = Column(ARRAY(TEXT()))
